"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.api = exports.assertValidApiInput = void 0;
const fs_1 = require("fs");
const object_1 = require("../augments/object");
const invalid_api_input_error_1 = require("../errors/invalid-api-input-error");
const migrate_library_1 = require("../migration/migrate-library");
const api_types_1 = require("./api-types");
function assertValidApiInput(input) {
    if (!input.libraryFilePath) {
        throw new invalid_api_input_error_1.InvalidApiInputError('libraryFilePath', 'Missing path.');
    }
    if (!fs_1.existsSync(input.libraryFilePath)) {
        throw new invalid_api_input_error_1.InvalidApiInputError('libraryFilePath', 'File does not exist: "${input.libraryFilePath}".');
    }
    if (!input.replacePaths || !input.replacePaths.length) {
        throw new invalid_api_input_error_1.InvalidApiInputError('replacePaths', 'No paths given.');
    }
    const invalidPaths = input.replacePaths.filter((replacePath) => {
        return !(replacePath.old &&
            (('delete' in replacePath && replacePath.delete) ||
                ('new' in replacePath && replacePath.new)));
    });
    if (invalidPaths.length) {
        throw new invalid_api_input_error_1.InvalidApiInputError('replacePaths', `Invalid paths encountered:\n${JSON.stringify(invalidPaths, null, 4)}`);
    }
    if (input.outputType && !object_1.getEnumTypedValues(api_types_1.MigrationOutput).includes(input.outputType)) {
        throw new invalid_api_input_error_1.InvalidApiInputError('outputType', `Unrecognized value: ${input.outputType}`);
    }
}
exports.assertValidApiInput = assertValidApiInput;
function api(input) {
    assertValidApiInput(input);
    migrate_library_1.migrateLibrary(input);
}
exports.api = api;
