"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.outputLibrary = void 0;
const fs_1 = require("fs");
const path_1 = require("path");
const plist_1 = require("plist");
const api_types_1 = require("../api/api-types");
const invalid_api_input_error_1 = require("../errors/invalid-api-input-error");
function outputLibrary({ libraryFilePath, newLibrary, outputType, loggingEnabled = true, }) {
    if (outputType === api_types_1.MigrationOutput.JsonObject) {
        loggingEnabled && console.info(`Returned JSON object representation of library plist.`);
        return newLibrary;
    }
    loggingEnabled && console.info(`Building plist of new library...`);
    const plistLibrary = plist_1.build(newLibrary);
    loggingEnabled && console.info(`Building finished`);
    if (outputType === api_types_1.MigrationOutput.PlistString) {
        loggingEnabled && console.info(`Returned JSON object representation of library plist.`);
        return { plist: plistLibrary };
    }
    else if (outputType === api_types_1.MigrationOutput.WriteToFile) {
        const extension = path_1.extname(libraryFilePath);
        const newPath = libraryFilePath.replace(extension, `.migrated${extension}`);
        loggingEnabled && console.info('Writing new library file...');
        fs_1.writeFileSync(newPath, plistLibrary);
        loggingEnabled && console.info(`New library written to: ${newPath}`);
        return { filePath: newPath };
    }
    throw new invalid_api_input_error_1.InvalidApiInputError('outputType', 'Unsupported output type.');
}
exports.outputLibrary = outputLibrary;
