"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.readLibraryString = exports.readLibraryFile = void 0;
const fs_1 = require("fs");
const plist_1 = require("plist");
const library_parse_error_1 = require("../../errors/library-parse-error");
const validate_library_1 = require("./validate-library");
function readLibraryFile(inputs) {
    if (!fs_1.existsSync(inputs.libraryFilePath)) {
        throw new library_parse_error_1.LibraryParseError(`Library file does not exist: ${inputs.libraryFilePath}`);
    }
    return readLibraryString({
        ...inputs,
        libraryString: fs_1.readFileSync(inputs.libraryFilePath).toString(),
    });
}
exports.readLibraryFile = readLibraryFile;
function readLibraryString({ libraryString, loggingEnabled = true, validationEnabled = true, }) {
    let parsedLibrary;
    try {
        loggingEnabled && console.info('Parsing started...');
        parsedLibrary = plist_1.parse(libraryString);
        loggingEnabled && console.info('Parsing finished');
    }
    catch (error) {
        if (error instanceof library_parse_error_1.LibraryParseError) {
            throw error;
        }
        else {
            throw new library_parse_error_1.LibraryParseError(`failed to parse library: ${String(error)}`);
        }
    }
    if (validationEnabled) {
        loggingEnabled && console.info('Validation started...');
        validate_library_1.assertValidLibrary(parsedLibrary);
        loggingEnabled && console.info('Validation finished');
        return parsedLibrary;
    }
    else {
        return parsedLibrary;
    }
}
exports.readLibraryString = readLibraryString;
